@@ -2,26 +2,44 @@ from symbl.jobs_api.Job import Job
 from symbl.jobs_api.JobStatus import JobStatus
 from symbl.conversations_api.ConversationsApi import ConversationsApi
 
+
+def validate_conversation_id(function):
+    def wrapper(*args, **kwargs):
+        self = args[0]
+        if self.get_conversation_id() != None:
+            return function(*args, **kwargs)
+        else:
+            raise ValueError('Conversation not initialized')
+    return wrapper
 class Conversation():
 
     __INTERVAL_TIME_IN_SECONDS = 30  ## in seconds
 
-    def __init__(self, conversationId: str, jobId: str=None,  wait=True, credentials=None):
-        
-        self.__conversation_id = conversationId
+    def __init__(self, conversation_id: str, job_id: str=None,  wait=True, credentials=None):
+
+        self.__conversation_id = conversation_id
         self.__wait = wait
         self.__credentials = credentials
         self.__conversation_api = ConversationsApi()
 
-        if jobId != None:
-            self.__job = Job(conversation_id=conversationId, job_id=jobId, wait=wait)
-            self.__monitorJob()
+        if job_id != None:
+            self.__job = Job(conversation_id=conversation_id, job_id=job_id, wait=wait)
+            self.__job.monitor_job(self, interval=self.__INTERVAL_TIME_IN_SECONDS, wait=self.__wait, credentials=self.__credentials)
+        else:
+            self.__job = None
     
     def get_conversation_id(self):
         return self.__conversation_id
     
     def get_job_status(self):
-        return self.__job.__job_status.value
+        if self.__job != None:
+            return self.__job.get_job_status()
+        return None
+
+    def get_job_id(self):
+        if self.__job != None:
+            return self.__job.get_job_id()
+        return None
 
     def on_complete(self, func):
         self.__job.on_complete(func)
@@ -31,26 +49,26 @@ class Conversation():
         self.__job.on_error(func)
         return self
 
-    def action_items(self):
+    @validate_conversation_id
+    def get_action_items(self):
         return self.__conversation_api.get_action_items(self.__conversation_id, credentials=self.__credentials)
 
-    def follow_ups(self):
+    @validate_conversation_id
+    def get_follow_ups(self):
         return self.__conversation_api.get_follow_ups(self.__conversation_id, credentials=self.__credentials)
-
-    def insights(self):
-        return self.__conversation_api.get_insights(self.__conversation_id, credentials=self.__credentials)
   
-    def members(self):  
+    @validate_conversation_id
+    def get_members(self):  
         return self.__conversation_api.get_members(self.__conversation_id, credentials=self.__credentials)
   
-    def messages(self, parameters={}):  
+    @validate_conversation_id
+    def get_messages(self, parameters={}):  
         return self.__conversation_api.get_messages(self.__conversation_id, credentials=self.__credentials, parameters=parameters)
   
-    def questions(self):  
+    @validate_conversation_id
+    def get_questions(self):  
         return self.__conversation_api.get_questions(self.__conversation_id, credentials=self.__credentials)
   
-    def topics(self, parameters={}):  
-        return self.__conversation_api.get_topics(self.__conversation_id, credentials=self.__credentials, parameters=parameters)
-        
-    def __monitorJob(self):
-        self.__job.monitor_job(self, interval=self.__INTERVAL_TIME_IN_SECONDS, wait=self.__wait, credentials=self.__credentials)
\ No newline at end of file
+    @validate_conversation_id
+    def get_topics(self, parameters={}):  
+        return self.__conversation_api.get_topics(self.__conversation_id, credentials=self.__credentials, parameters=parameters)
\ No newline at end of file
