@@ -1,4 +1,4 @@
-from symbl.utils.Helper import correct_boolean_values
+from symbl.utils.Helper import correct_boolean_values, change_camel_case_to_snake_case
 from symbl.utils.Logger import Log
 from symbl.Conversations import Conversation
 from symbl import AuthenticationToken
@@ -38,7 +38,9 @@ class Text():
         if payload == None:
             raise ValueError("Please enter a valid payload.")
 
-        response = self.__async_api_rest.add_text(body=payload, **correct_boolean_values(parameters))
+        params = change_camel_case_to_snake_case(parameters)
+
+        response = self.__async_api_rest.add_text(body=payload, **correct_boolean_values(params))
         Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
@@ -55,7 +57,9 @@ class Text():
         if conversation_id == None or len(conversation_id) == 0:
             raise ValueError("Please enter a valid conversationId")
 
-        response = self.__async_api_rest.append_text(conversation_id, body=payload, **correct_boolean_values(parameters))
+        params = change_camel_case_to_snake_case(parameters)
+
+        response = self.__async_api_rest.append_text(conversation_id, body=payload, **correct_boolean_values(params))
         Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
\ No newline at end of file
